# 注意1：首次执行代码前请确保安装PyEMD、ewtpy、numpy、Matplotlib包，
# 在命令行窗口执行下述指令进行安装：
# pip install EMD-signal
# pip install ewtpy
# pip install numpy
# pip install Matplotlib

# 注意2：此程序运行过程中会绘制图像，图像会使程序阻塞，关闭图像窗口后程序才会继续运行。

import numpy as np
import matplotlib.pyplot as plt
from funEMDs import kEMDs,pEMDs,pEMDsandFFT
import time
import pandas as pd

# 类EMD分解画图测试程序
# 代码说明：http://khsci.com/docs/index.php/emdspy/
# 更多说明：https://zhuanlan.zhihu.com/p/704773627/

# 1. 导入信号
FsOrT = 1000  # 采样频率
data = pd.read_excel('data.xlsx', sheet_name='Sheet1', usecols='A', skiprows=1).to_numpy().flatten()  # 数据导入

# 2. EMD分解案例
# 2.1 参数设置
options = {'MaxNumIMFs': 3}  # 最大的IMF数量，这个数量中包含趋势项
# 2.2 绘制分解图
elapsedTime = pEMDs(data, FsOrT, 'EMD', options)
# 2.3 绘制分解图及频谱图
elapsedTime = pEMDsandFFT(data, FsOrT, 'EMD', options)
print(f'EMD分解程序运行时间为: {elapsedTime:.2f}秒')  # 输出运行时间

# 3. EEMD分解案例
# 3.1 参数设置
options = {'Nstd': 0.2, 'NE': 100}  # Nstd为附加噪声标准差与Y标准差之比
# 3.2 绘制分解图
elapsedTime = pEMDs(data, FsOrT, 'EEMD', options)
# 3.3 绘制分解图及频谱图
elapsedTime = pEMDsandFFT(data, FsOrT, 'EEMD', options)
print(f'EEMD分解程序运行时间为: {elapsedTime:.2f}秒')  # 输出运行时间

# 4. CEEMD分解案例
# 4.1 参数设置
options = {'Nstd': 0.2, 'NE': 100}  # Nstd为附加噪声标准差与Y标准差之比
# 4.2 绘制分解图
elapsedTime = pEMDs(data, FsOrT, 'CEEMD', options)
# 4.3 绘制分解图及频谱图
elapsedTime = pEMDsandFFT(data, FsOrT, 'CEEMD', options)
print(f'CEEMD分解程序运行时间为: {elapsedTime:.2f}秒')  # 输出运行时间

# 5. CEEMDAN分解案例
# 5.1 参数设置
options = {'Nstd': 0.2, 'NE': 100, 'MaxIter': 1000}  # MaxIter - 最大迭代次数
# 5.2 绘制分解图
elapsedTime = pEMDs(data, FsOrT, 'CEEMDAN', options)
# 5.3 绘制分解图及频谱图
elapsedTime = pEMDsandFFT(data, FsOrT, 'CEEMDAN', options)
print(f'CEEMDAN分解程序运行时间为: {elapsedTime:.2f}秒')  # 输出运行时间

# 6. ICEEMDAN分解案例
# 6.1 参数设置
options = {'Nstd': 0.2, 'NE': 100, 'MaxIter': 1000}  # MaxIter - 最大迭代次数
# 6.2 绘制分解图
elapsedTime = pEMDs(data, FsOrT, 'ICEEMDAN', options)
# 6.3 绘制分解图及频谱图
elapsedTime = pEMDsandFFT(data, FsOrT, 'ICEEMDAN', options)
print(f'ICEEMDAN分解程序运行时间为: {elapsedTime:.2f}秒')  # 输出运行时间

# 7. EWT分解案例
# 7.1 参数设置
options = {'MaxNumIMFs': 3}  # 最大的IMF数量
# 7.2 绘制分解图
elapsedTime = pEMDs(data, FsOrT, 'EWT', options)
# 7.3 绘制分解图及频谱图
elapsedTime = pEMDsandFFT(data, FsOrT, 'EWT', options)
print(f'EWT分解程序运行时间为: {elapsedTime:.2f}秒')  # 输出运行时间

# 8. VMD分解案例
# 8.1 参数设置
options = {'alpha': 2000, 'tol': 1e-7, 'K': 4}  # K - 指定分解模态数
# 8.2 绘制分解图
elapsedTime = pEMDs(data, FsOrT, 'VMD', options)
# 8.3 绘制分解图及频谱图
elapsedTime = pEMDsandFFT(data, FsOrT, 'VMD', options)
print(f'VMD分解程序运行时间为: {elapsedTime:.2f}秒')  # 输出运行时间

## 关于完整版代码：
# 公开版代码的函数文件为pyd文件，可以被调用，但无法查看代码。
# 完整版代码中全部为py文件，py文件可以查看源码并自由修改，画图无水印
# 完整版不限制待分解的数据长度
# 完整版可导出分解结果、重构误差值等

# 如果需要封装好的函数的源码，可在下述连接（完整版）获取：
# http://khsci.com/docs/index.php/emdspy/
# 编程不易，感谢支持~